************
Contributors
************

.. note::
  We are actively looking for new contributors for climpred! Riley moved to McKinsey's
  Climate Analytics team. Aaron is finishing his PhD, but will stay in academia.
  We especially hope for python enthusiasts from seasonal, subseasonal or weather
  prediction community. In our past coding journey, collaborative coding, feedbacking
  issues and pull requests advanced our code and thinking about forecast verification
  more than we could have ever expected.
  `Aaron <https://github.com/aaronspring/>`_ can provide guidance on
  implementing new features into climpred. Feel free to implement
  your own new feature or take a look at the
  `good first issue <https://github.com/pangeo-data/climpred/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22>`_
  tag in the issues. Please reach out to us via `gitter <https://gitter.im/climpred>`_.


Core Developers
===============
* Riley X. Brady (`github <https://github.com/bradyrx/>`__)
* Aaron Spring (`github <https://github.com/aaronspring/>`__)

Contributors
============
* Andrew Huang (`github <https://github.com/ahuang11/>`__)
* Kathy Pegion (`github <https://github.com/kpegion/>`__)
* Anderson Banihirwe (`github <https://github.com/andersy005/>`__)
* Ray Bell (`github <https://github.com/raybellwaves/>`__)

For a list of all the contributions, see the github
`contribution graph <https://github.com/pangeo-data/climpred/graphs/contributors>`_.
